@@ -50,8 +50,6 @@ module JSON
       end
     end
 
-    private
-
     def rsa?
       self[:kty]&.to_sym == :RSA
     end
@@ -64,12 +62,6 @@ module JSON
       self[:kty]&.to_sym == :oct
     end
 
-    def calculate_default_kid
-      self[:kid] = thumbprint
-    rescue
-      # ignore
-    end
-
     def normalize
       case
       when rsa?
@@ -95,6 +87,14 @@ module JSON
       end
     end
 
+    private
+
+    def calculate_default_kid
+      self[:kid] = thumbprint
+    rescue
+      # ignore
+    end
+
     def to_rsa_key
       e, n, d, p, q, dp, dq, qi = [:e, :n, :d, :p, :q, :dp, :dq, :qi].collect do |key|
         if self[key]
@@ -127,6 +127,8 @@ module JSON
         'secp384r1'
       when :'P-521'
         'secp521r1'
+      when :secp256k1
+        'secp256k1'
       else
         raise UnknownAlgorithm.new('Unknown EC Curve')
       end
